@@ -1,21 +1,25 @@
 #ifndef PERMUTE_RESULTS_H
 #define PERMUTE_RESULTS_H
 
-#include <CombPermUtils.h>
-#include <ConstraintsUtils.h>
+#include "CombPermUtils.h"
+#include "ConstraintsUtils.h"
+#include <memory>
 
 template <typename typeMatrix, typename typeVector>
 void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
-                   int numRows, std::vector<int> z, unsigned long int count,
-                   bool nonTrivial, typeMatrix permuteMatrix, funcPtr<typeVector> myFun) {
+                   int numRows, std::vector<int> &z, unsigned long int count,
+                   bool nonTrivial, typeMatrix &permuteMatrix, funcPtr<typeVector> myFun) {
     
-    unsigned long int uN = n, uR = r, uRowN = numRows;
-    unsigned long int lastElem = n - 1;
-    unsigned long int lastCol = r - 1, pentultimate = n - 2;
+    const unsigned long int uN = n;
+    const unsigned long int uR = r;
+    const unsigned long int uRowN = numRows;
+    const unsigned long int lastElem = n - 1;
+    const unsigned long int lastCol = r - 1;
+    const unsigned long int pentultimate = n - 2;
     std::vector<typeVector> vPass(uR);
     
     if (repetition) {
-        int lastElemInt = lastElem;
+        const int lastElemInt = lastElem;
         
         for (; count < uRowN; ++count) {
             for (std::size_t j = 0; j < uR; ++j) {
@@ -37,8 +41,8 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
         
     } else if (nonTrivial) {
         
-        unsigned long int numR1 = numRows - 1;
-        int *arrPerm = new int[uN];
+        const unsigned long int numR1 = numRows - 1;
+        auto arrPerm = std::make_unique<int[]>(uN);
 
         for (std::size_t i = 0; i < uN; ++i)
             arrPerm[i] = z[i];
@@ -51,7 +55,7 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
                 }
                 
                 permuteMatrix(count, uR) = myFun(vPass, uR);
-                nextFullPerm(arrPerm, lastElem, pentultimate);
+                nextFullPerm(arrPerm.get(), lastElem, pentultimate);
             }
         } else {
             for (; count < numR1; ++count) {
@@ -61,7 +65,7 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
                 }
                 
                 permuteMatrix(count, uR) = myFun(vPass, uR);
-                nextPartialPerm(arrPerm, uR, lastCol, uN, lastElem);
+                nextPartialPerm(arrPerm.get(), uR, lastCol, uN, lastElem);
             }
         }
         
@@ -72,7 +76,6 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
         }
         
         permuteMatrix(numR1, uR) = myFun(vPass, uR);
-        delete[] arrPerm;
         
     } else {
         
@@ -81,11 +84,11 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
             unsigned long int segment = maxN / uN;
             phaseOne = (uRowN < segment) ? uRowN : segment;
 
-            int *indexMat = new int[phaseOne * uR];
-            int *arrPerm = new int[uN];
+            auto indexMat = std::make_unique<int[]>(phaseOne * uR);
+            auto arrPerm = std::make_unique<int[]>(uN);
             
             for (std::size_t i = 0; i < uN; ++i)
-                arrPerm[i] = (int) i;
+                arrPerm[i] = static_cast<int>(i);
 
             if (r == n) {
                 for (std::size_t i = 0, k = 0; i < phaseOne; ++i) {
@@ -96,7 +99,7 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
                     }
 
                     permuteMatrix(i, uR) = myFun(vPass, uR);
-                    nextFullPerm(arrPerm, lastElem, pentultimate);
+                    nextFullPerm(arrPerm.get(), lastElem, pentultimate);
                 }
             } else {
                 for (std::size_t i = 0, k = 0; i < phaseOne; ++i) {
@@ -107,7 +110,7 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
                     }
                     
                     permuteMatrix(i, uR) = myFun(vPass, uR);
-                    nextPartialPerm(arrPerm, uR, lastCol, uN, lastElem);
+                    nextPartialPerm(arrPerm.get(), uR, lastCol, uN, lastElem);
                 }
             }
             
@@ -132,9 +135,6 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
                     permuteMatrix(i, uR) = myFun(vPass, uR);
                 }
             }
-    
-            delete[] indexMat;
-            delete[] arrPerm;
         } else {
             permuteMatrix(0, 0) = v[0];
         }
@@ -144,21 +144,23 @@ void PermuteGenRes(int n, int r, std::vector<typeVector> &v, bool repetition,
 template <typename typeMatrix, typename typeVector>
 void MultisetPermRes(int n, int r, std::vector<typeVector> &v, int numRows,
                      unsigned long int count, std::vector<int> &z,
-                     typeMatrix permuteMatrix, funcPtr<typeVector> myFun) {
+                     typeMatrix &permuteMatrix, funcPtr<typeVector> myFun) {
     
-    unsigned long int lenFreqs = z.size();
-    int *arrPerm = new int[lenFreqs];
+    const unsigned long int lenFreqs = z.size();
+    auto arrPerm = std::make_unique<int[]>(lenFreqs);
     std::vector<typeVector> vPass(r);
     
-    unsigned long int uN = n, numR1 = numRows - 1;
-    unsigned long int uR = r, lastCol = r - 1;
-    unsigned long int lastElem = lenFreqs - 1;
+    const unsigned long int uR = r;
+    const unsigned long int uN = n;
+    const unsigned long int lastCol = r - 1;
+    const unsigned long int numR1 = numRows - 1;
+    const unsigned long int lastElem = lenFreqs - 1;
     
     for (std::size_t j = 0; j < lenFreqs; ++j)
         arrPerm[j] = z[j];
     
     if (uR == lenFreqs) {
-        unsigned long int pentultimate = lenFreqs - 2;
+        const unsigned long int pentultimate = lenFreqs - 2;
         
         for (; count < numR1; ++count) {
             for (std::size_t j = 0; j < uR; ++j) {
@@ -167,7 +169,7 @@ void MultisetPermRes(int n, int r, std::vector<typeVector> &v, int numRows,
             }
             
             permuteMatrix(count, uR) = myFun(vPass, uR);
-            nextFullPerm(arrPerm, lastElem, pentultimate);
+            nextFullPerm(arrPerm.get(), lastElem, pentultimate);
         }
     } else {
         for (; count < numR1; ++count) {
@@ -177,7 +179,7 @@ void MultisetPermRes(int n, int r, std::vector<typeVector> &v, int numRows,
             }
             
             permuteMatrix(count, uR) = myFun(vPass, uR);
-            nextPartialPerm(arrPerm, uR, lastCol, uN, lastElem);
+            nextPartialPerm(arrPerm.get(), uR, lastCol, uN, lastElem);
         }
     }
     
@@ -188,7 +190,6 @@ void MultisetPermRes(int n, int r, std::vector<typeVector> &v, int numRows,
     }
     
     permuteMatrix(numR1, uR) = myFun(vPass, uR);
-    delete[] arrPerm;
 }
 
 #endif
