@@ -357,11 +357,7 @@ namespace PrimeCounting {
 SEXP PrimeCountRcpp(SEXP Rn, SEXP RNumThreads, int maxThreads) {
     double dblNum;
     CleanConvert::convertPrimitive(Rn, dblNum, "n");
-
-    if (dblNum < 1 || dblNum > Significand53)
-        Rcpp::stop("n must be a positive number less than 2^53");
-
-    const int64_t n = dblNum;
+    const int64_t n = static_cast<int64_t>(dblNum);
     
     if (n < 100000) {
         if (n < 10) {
@@ -440,18 +436,12 @@ SEXP MotleyContainer(SEXP Rb1, SEXP Rb2, bool isEuler,
     bool isNamed = CleanConvert::convertLogical(RNamed, namedObject);
     CleanConvert::convertPrimitive(Rb1, bound1, "bound1");
     
-    if (bound1 <= 0 || bound1 > Significand53)
-        Rcpp::stop("bound1 must be a positive number less than 2^53");
-    
     if (Rf_isNull(Rb2)) {
         bound2 = 1;
     } else {
         CleanConvert::convertPrimitive(Rb2, bound2, "bound2");
     }
     
-    if (bound2 <= 0 || bound2 > Significand53)
-        Rcpp::stop("bound2 must be a positive number less than 2^53");
-    
     if (bound1 > bound2) {
         myMax = std::floor(bound1);
         myMin = std::ceil(bound2);
@@ -496,20 +486,14 @@ SEXP EratosthenesRcpp(SEXP Rb1, SEXP Rb2, SEXP RNumThreads, int maxCores, int ma
     
     double bound1, bound2;
     int_fast64_t myMax, myMin;
-    CleanConvert::convertPrimitive(Rb1, bound1, "bound1", false, false);
-    
-    if (bound1 <= 0 || bound1 > Significand53)
-        Rcpp::stop("bound1 must be a positive number less than 2^53");
+    CleanConvert::convertPrimitive(Rb1, bound1, "bound1", true, false);
     
     if (Rf_isNull(Rb2)) {
         bound2 = 1;
     } else {
-        CleanConvert::convertPrimitive(Rb2, bound2, "bound2", false, false);
+        CleanConvert::convertPrimitive(Rb2, bound2, "bound2", true, false);
     }
     
-    if (bound2 <= 0 || bound2 > Significand53)
-        Rcpp::stop("bound2 must be a positive number less than 2^53");
-    
     if (bound1 > bound2) {
         myMax = static_cast<int_fast64_t>(std::floor(bound1));
         myMin = static_cast<int_fast64_t>(std::ceil(bound2));
@@ -522,7 +506,17 @@ SEXP EratosthenesRcpp(SEXP Rb1, SEXP Rb2, SEXP RNumThreads, int maxCores, int ma
         return Rcpp::IntegerVector();
     
     if (myMin <= 2) myMin = 1;
-    if (myMin == myMax) {++myMax;}
+    
+    if (myMin == myMax) {
+        if (myMax % 2) {
+            ++myMax;
+        } else {
+            if (myMax > std::numeric_limits<int>::max())
+                return Rcpp::NumericVector();
+            else
+                return Rcpp::IntegerVector();
+        }
+    }
     
     int nThreads = 1;
     if (!Rf_isNull(RNumThreads))
