@@ -17,6 +17,6 @@ test_that("primeCount generates correct numbers", {
 test_that("primeCount produces appropriate error messages", {
     expect_error(primeCount(0), "must be a positive")
     expect_error(primeCount(-1), "must be a positive")
-    expect_error(primeCount(2^53), "must be a positive number less")
+    expect_error(primeCount(2^53), "n must be less than")
     expect_error(primeCount("100000"), "must be of type numeric or integer")
 })
